function x = createsine(f, fs, len)
%x = createsine(f, fs, len)
%x = a sinewave sample
%f = frequency of sine wave in hertz
%fs = sampling frequency in hertz
%len = length of sample in seconds

t = (0:(1/fs):len)';

x = sin(2*pi*t*f);